@@ -346,8 +346,8 @@ def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWor
         local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s-%s.json deploy/api/config/keyset.json' % (javaEnv, shard))
-            local('aws s3 cp s3://topopps-prod-x/application-%s-%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/api/config/keyset.json' % (javaEnv, shard))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
     	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
@@ -367,9 +367,9 @@ def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWor
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
 
         if prodSecrets in TRUTH_VALUES:
-            local('aws s3 cp s3://topopps-prod-x/keyset-%s-%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
             local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
